#
# spec file for package python-pyreadstat
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-pyreadstat
Version:        1.2.7
Release:        1.2
Summary:        Package to read and write statistical data files into pandas
License:        Apache-2.0
URL:            https://github.com/Roche/pyreadstat
Source:         https://github.com/Roche/pyreadstat/archive/v%{version}.tar.gz#/pyreadstat-%{version}.tar.gz
BuildRequires:  %{python_module Cython >= 3}
BuildRequires:  %{python_module devel}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  %{python_module pandas >= 0.24.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  glibc-devel
BuildRequires:  python-rpm-macros
BuildRequires:  zlib-devel
Requires:       python-numpy
Requires:       python-pandas >= 0.24.0
%python_subpackages

%description
Reads and Writes SAS, SPSS and Stata files into pandas data frames.

%prep
%setup -q -n pyreadstat-%{version}

%build
export CFLAGS="%{optflags} -fno-strict-aliasing"
%python_build

%install
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitearch}

%check
mv pyreadstat pyreadstat_temp
rm -rf build _build.*
export PYTHONDONTWRITEBYTECODE=1
%{python_expand export PYTHONPATH=%{buildroot}%{$python_sitearch}
rm -rf build _build.*
$python -B tests/test_basic.py
}
mv pyreadstat_temp pyreadstat

%files %{python_files}
%doc README.md change_log.md
%license LICENSE
%{python_sitearch}/pyreadstat*.egg-info
%{python_sitearch}/pyreadstat

%changelog
* Sat Mar 16 2024 Dirk Müller <dmueller@suse.com>
- update to 1.2.7:
  * Fixing warnings in new pandas version 2.2.1
  * Remove string encoding for read_por
  * Fix read in chunks when output is dict
* Tue Jan  9 2024 Dirk Müller <dmueller@suse.com>
- update to 1.2.6:
  * correcting bug when writing files with character columns with
    all missing, character length set to 1
  * Correcting bug for datetime64[us
  * Added modification_time and creation_time to metadata
  * added datetime64[us in addition to ns for improvement when
    writing.
* Thu Aug 31 2023 Markéta Machová <mmachova@suse.com>
- update to 1.2.3
  * changes introduced for compatibility with cython 3.0.0.
    Cython 0.29 no longer supported. Python 2.7 no longer supported.
* Tue Jun 27 2023 Markéta Machová <mmachova@suse.com>
- update to 1.2.2
  * added num_rows to multiprocessing to allow processing of xport,
    por and sav files not having the number of rows in the metadata.
* Mon Mar 13 2023 Dirk Müller <dmueller@suse.com>
- update to 1.2.1:
  * Readstat source updated to version 1.1.9
  * introduced recognition for pandas datatype datetime64[ns,
    UTC] and other datetime64 types when writing,
    so that this column type gets correctly written as datetime
  * introduced extra_datetime_formats and extra_date_formats
    arguments for read functions, cleaned the list of
    sas date, datetime and time formats to exclude those not
    directly convertible to python objects
  * improved performace of writer when there are datetime64
    columns
* Mon Feb 13 2023 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.2.0:
  * added pyproject.toml
  * Updated Readstat code to Release 1.1.8
  * Solved issue with duplicated columns, #188
  * new parameter output_type to switch between returning a pandas
    dataframe or a dict of numpy arrays, partial solution for #184
  * Implemented row_compression for writing sav files, solves #185
  * Added new date formats for SAS and SPSS solves #170, #171
  * Added check missing_range type against variable type solves #180
  * Removed np.float, solves #160
* Wed Feb 16 2022 Dirk Müller <dmueller@suse.com>
- update to 1.1.4:
  * Included new pandas datatypes Float32Dtype and Float64Dtype when writing.
  * Forcing cythonization when installing from source
  [#] Updated Readstat source to version 1.1.17
  * Improved error when reading dates and finding a string
  * repaired not reading correctly metadata with multiprocessing
  [#] correction when reading file paths in python <3.7
  * Using os.fsencode when reading file paths to support file system
    encoding and Path-like objects
  * Updated Readstat source to version 1.1.6
  * Accepting dict as the column_label parameter for writing functions
* Mon Apr 19 2021 Steve Kowalik <steven.kowalik@suse.com>
- Update to 1.1.0:
  * added meta.readstat_variable_types to track the type of binary
    variable in the original file.
  * Adding better error message for not accepting certain files types in
    multiprocessing, solves #105
  * Fixing #106 writing failing when row 0 is removed from dataframe.
  * Removing numpy deprecated objects solves #107.
  * Adding support for pathlib.Path, soves #110.
  * fixing order of categories
  * Added formats_as_ordered_category to get an ordered category.
  * Added value_formats in order to be able to set the variable format when
    writing.
- Do not build on Python 3.6, due to no NumPy.
* Mon Dec 28 2020 andy great <andythe_great@pm.me>
- Update to version 1.0.6.
  * Updated Readstat to version 1.1.5, this fixes: reading sas7bdat
    file labels, reading newer por files date-like columns, and few
    others.
  * Corrected writing columns with numpy.float32 format.
- Updates for 1.0.5
  * fixed sharing permissions when reading files on windows,
    fixes #87
- Updates for 1.0.4
  * read_file_in_chunks can read chunks with multiprocessing.
- Updates for 1.0.3
  * Improved performance specially for big files.
  * added a method to read files in parallel
  * added license information to setup.py
- Updates for 1.0.2
  * Updated default widths for DATE and DATETIME formats
    (from Readstat src). That make the files readable both in SPSS
    and PSPP, solves issue #69.
  * added support for binary compressed sas7bdat files
  * fixes writing XPT files v8 that can be read in SAS. Reading XPT v8 improved.
  * fixes writing files with NaT values.
  * fixes #72: variable display width with long strings.
  * fixes #70: variable_measures not set when writing sav files
- Updates for 1.0.1
  * fixes issue #67
* Tue Jul 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 1.0.0
  * improved error messages when column names have spaces
  * updated readstat to release 1.1.3: improved support for columns with utf-8 characters.
  * bumped version to first stable release as the library looks stable
  * added capability to set_value_labels to handle subset of dataframes
  * added capacity to read and write files with paths starting with tilde
  * few bugfixes
* Fri Sep 13 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 0.2.9:
  * metadata updates
* Fri Aug 16 2019 Todd R <toddrme2178@gmail.com>
- Update to 0.2.8
  * deleted dist files
- Remove upstream-included fix_no_return_in_nonvoid_function.patch
* Mon Jul 22 2019 Todd R <toddrme2178@gmail.com>
- Initial version
- Add fix_no_return_in_nonvoid_function.patch
  to fix no-return-in-nonvoid-function error
  From gh#Roche/pyreadstat#36
